==> resh-5.0.0.16-py3-none-any.whl: reface/static/js/line_building.js <==
var devices = [];
var dali_type;

$(document).ready(function () {

    const chatSocket = new WebSocket('ws://' + window.location.host + '/rapida/ws/builder/' + room + '/');

    chatSocket.onopen = function() {
        console.log('Opened');
        // chatSocket.send(JSON.stringify({
        //     'type': 'chat_message',
        //     'message': 'Hello!'}
        // ));
    };
    chatSocket.onclose = function(e) {
        alert('Соединение с сервером разорвано');
    };
    chatSocket.onmessage = function (e) {
        const data = JSON.parse(e.data);

        console.log(data);
        if (data.hasOwnProperty('found')) {
            onFound(data['found']);
        } else if (data.hasOwnProperty('prefixed')) {
            onPrefixed(data['prefixed']);
        } else if (data.hasOwnProperty('fixed')) {
            onFixed(...data['fixed']);
        } else if (data.hasOwnProperty('progress')) {
            updateProgress(data['progress']);
        } else if (data.hasOwnProperty('status')) {
            dali_type = data['status']['dali_type'];
            data['status']['addresses'].forEach(address => onFound(address));
            for (var addr in data['status']['fixed']) {
                onFixed(addr, ...data['status']['fixed'][addr]);
            }
            updateProgress(data['status']['progress']);
        } else {
        }
    };
});

function onFound(address) {
    $('#addressed-table table').each(function (index, table) {
        const row = table.insertRow();
        row.insertCell().textContent = '' + (table.rows.length - 1);
        row.insertCell().textContent = address;
    });

    if (!devices.includes('D' + address)) devices.push('D'+address);
}

function onPrefixed(address) {
    $('#addressed-table table').each(function (index, table) {
        if ($('#doubled-' + address).length === 0) {
            createFixedRow(table, address);
        }
    });
}

function createFixedRow(table, address) {
    const row = table.insertRow();
    row.id = 'doubled-' + address;
    row.insertCell().textContent = table.rows.length - 1;
    row.insertCell().textContent = address;
    return row;
}

function onFixed(old, ...restored) {
    if (!devices.includes('D' + old)) devices.push('D'+old);
    $('#addressed-table table').each(function (index, table) {
        $(table).find('#fixed-th').show();
        var rows = $(table).find('#doubled-' + old);
        if (rows.length === 0) {
            rows.push(createFixedRow(table, old))
        }
        restored.forEach(r => {
            rows[0].insertCell().textContent = r;
            if (!devices.includes('D' + r)) devices.push('D'+r);
        });
    });
}

function updateProgress(value) {
    $('.progress-bar').css('width', value+'%')
        .attr('aria-valuenow', value)[0]
        .textContent = value === 100 ? 'Готово!' : value + '%';

    if (value === 100 && dali_type) {
        if ($('#addressed-table table tr').length > 1) {
            $('#actions').removeClass('hidden');
        }
    }
}

function goto(dest) {
    location.href = location.href.split('builder')[0] + dest + '?' +
        [
            'dali_type' + '=' + dali_type,
            dali_type + '=' + devices.join(',')
        ].join('&');
}

==> resh-5.1.0.9-py3-none-any.whl: reface/static/js/line_building.js <==
var devices = [];
var dali_type;

$(document).ready(function () {

    const chatSocket = new WebSocket('ws://' + window.location.host + '/rapida/ws/builder/' + room + '/');

    chatSocket.onopen = function() {
        console.log('Opened');
        // chatSocket.send(JSON.stringify({
        //     'type': 'chat_message',
        //     'message': 'Hello!'}
        // ));
    };
    chatSocket.onclose = function(e) {
        alert('Соединение с сервером разорвано');
    };
    chatSocket.onmessage = function (e) {
        const data = JSON.parse(e.data);

        console.log(data);
        if (data.hasOwnProperty('found')) {
            onFound(data['found']);
        } else if (data.hasOwnProperty('prefixed')) {
            onPrefixed(data['prefixed']);
        } else if (data.hasOwnProperty('fixed')) {
            onFixed(...data['fixed']);
        } else if (data.hasOwnProperty('progress')) {
            updateProgress(data['progress']);
        } else if (data.hasOwnProperty('status')) {
            dali_type = data['status']['dali_type'];
            if (data.status.hasOwnProperty('addresses')) {
                data['status']['addresses'].forEach(address => onFound(address));
            }
            if (data.status.hasOwnProperty('fixed')) {
                for (var addr in data['status']['fixed']) {
                    if (data['status']['fixed'].hasOwnProperty(addr)) {
                        onFixed(addr, ...data['status']['fixed'][addr]);
                    }
                }
            }
            if (data.status.hasOwnProperty('progress')) {
                updateProgress(data['status']['progress']);
            }
            if (data.status.error) alert(data.status.error);
        }  else if (data.hasOwnProperty('error')) {
            console.error(data.error);
            alert(data.error);
        } else {
        }
    };
});

function onFound(address) {
    $('#addressed-table table').each(function (index, table) {
        const row = table.insertRow();
        row.insertCell().textContent = '' + (table.rows.length - 1);
        row.insertCell().textContent = address;
    });

    if (!devices.includes('D' + address)) devices.push('D'+address);
}

function onPrefixed(address) {
    $('#addressed-table table').each(function (index, table) {
        if ($('#doubled-' + address).length === 0) {
            createFixedRow(table, address);
        }
    });
}

function createFixedRow(table, address) {
    const row = table.insertRow();
    row.id = 'doubled-' + address;
    row.insertCell().textContent = table.rows.length - 1;
    row.insertCell().textContent = address;
    return row;
}

function onFixed(old, ...restored) {
    if (!devices.includes('D' + old)) devices.push('D'+old);
    $('#addressed-table table').each(function (index, table) {
        $(table).find('#fixed-th').show();
        var rows = $(table).find('#doubled-' + old);
        if (rows.length === 0) {
            rows.push(createFixedRow(table, old))
        }
        restored.forEach(r => {
            rows[0].insertCell().textContent = r;
            if (!devices.includes('D' + r)) devices.push('D'+r);
        });
    });
}

function updateProgress(value) {
    $('.progress-bar').css('width', value+'%')
        .attr('aria-valuenow', value)[0]
        .textContent = value + '%';

    if (value === 100 && dali_type) {
        if ($('#addressed-table table tr').length > 1) {
            $('#actions').removeClass('hidden');
        }
    }
}

function goto(dest) {
    location.href = location.href.split('builder')[0] + dest + '?' +
        [
            'dali_type' + '=' + dali_type,
            dali_type + '=' + devices.join(',')
        ].join('&');
}
